@@ -2,7 +2,7 @@
 # pylint: disable=R0903
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2016
+# Copyright (C) 2015-2020
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -21,13 +21,25 @@
 
 
 class ChatAction(object):
-    """This object represents a Telegram ChatAction."""
+    """Helper class to provide constants for different chatactions."""
 
-    TYPING = 'typing'
-    UPLOAD_PHOTO = 'upload_photo'
-    RECORD_VIDEO = 'record_video'
-    UPLOAD_VIDEO = 'upload_video'
-    RECORD_AUDIO = 'record_audio'
-    UPLOAD_AUDIO = 'upload_audio'
-    UPLOAD_DOCUMENT = 'upload_document'
     FIND_LOCATION = 'find_location'
+    """:obj:`str`: 'find_location'"""
+    RECORD_AUDIO = 'record_audio'
+    """:obj:`str`: 'record_audio'"""
+    RECORD_VIDEO = 'record_video'
+    """:obj:`str`: 'record_video'"""
+    RECORD_VIDEO_NOTE = 'record_video_note'
+    """:obj:`str`: 'record_video_note'"""
+    TYPING = 'typing'
+    """:obj:`str`: 'typing'"""
+    UPLOAD_AUDIO = 'upload_audio'
+    """:obj:`str`: 'upload_audio'"""
+    UPLOAD_DOCUMENT = 'upload_document'
+    """:obj:`str`: 'upload_document'"""
+    UPLOAD_PHOTO = 'upload_photo'
+    """:obj:`str`: 'upload_photo'"""
+    UPLOAD_VIDEO = 'upload_video'
+    """:obj:`str`: 'upload_video'"""
+    UPLOAD_VIDEO_NOTE = 'upload_video_note'
+    """:obj:`str`: 'upload_video_note'"""
