@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2017
+# Copyright (C) 2015-2020
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -28,6 +28,7 @@ class Sticker(TelegramObject):
         file_id (:obj:`str`): Unique identifier for this file.
         width (:obj:`int`): Sticker width.
         height (:obj:`int`): Sticker height.
+        is_animated (:obj:`bool`): True, if the sticker is animated.
         thumb (:class:`telegram.PhotoSize`): Optional. Sticker thumbnail in the .webp or .jpg
             format.
         emoji (:obj:`str`): Optional. Emoji associated with the sticker.
@@ -35,11 +36,13 @@ class Sticker(TelegramObject):
         mask_position (:class:`telegram.MaskPosition`): Optional. For mask stickers, the position
             where the mask should be placed.
         file_size (:obj:`int`): Optional. File size.
+        bot (:class:`telegram.Bot`): Optional. The Bot to use for instance methods.
 
     Args:
         file_id (:obj:`str`): Unique identifier for this file.
         width (:obj:`int`): Sticker width.
         height (:obj:`int`): Sticker height.
+        is_animated (:obj:`bool`): True, if the sticker is animated.
         thumb (:class:`telegram.PhotoSize`, optional): Sticker thumbnail in the .webp or .jpg
             format.
         emoji (:obj:`str`, optional): Emoji associated with the sticker
@@ -48,7 +51,8 @@ class Sticker(TelegramObject):
         mask_position (:class:`telegram.MaskPosition`, optional): For mask stickers, the
             position where the mask should be placed.
         file_size (:obj:`int`, optional): File size.
-        **kwargs (obj:`dict`): Arbitrary keyword arguments.
+        **kwargs (obj:`dict`): Arbitrary keyword arguments.7
+        bot (:class:`telegram.Bot`, optional): The Bot to use for instance methods.
 
     """
 
@@ -56,22 +60,26 @@ class Sticker(TelegramObject):
                  file_id,
                  width,
                  height,
+                 is_animated,
                  thumb=None,
                  emoji=None,
                  file_size=None,
                  set_name=None,
                  mask_position=None,
+                 bot=None,
                  **kwargs):
         # Required
         self.file_id = str(file_id)
         self.width = int(width)
         self.height = int(height)
+        self.is_animated = is_animated
         # Optionals
         self.thumb = thumb
         self.emoji = emoji
         self.file_size = file_size
         self.set_name = set_name
         self.mask_position = mask_position
+        self.bot = bot
 
         self._id_attrs = (self.file_id,)
 
@@ -85,7 +93,7 @@ class Sticker(TelegramObject):
         data['thumb'] = PhotoSize.de_json(data.get('thumb'), bot)
         data['mask_position'] = MaskPosition.de_json(data.get('mask_position'), bot)
 
-        return cls(**data)
+        return cls(bot=bot, **data)
 
     @classmethod
     def de_list(cls, data, bot):
@@ -94,6 +102,24 @@ class Sticker(TelegramObject):
 
         return [cls.de_json(d, bot) for d in data]
 
+    def get_file(self, timeout=None, **kwargs):
+        """Convenience wrapper over :attr:`telegram.Bot.get_file`
+
+        Args:
+            timeout (:obj:`int` | :obj:`float`, optional): If this value is specified, use it as
+                the read timeout from the server (instead of the one specified during creation of
+                the connection pool).
+            **kwargs (:obj:`dict`): Arbitrary keyword arguments.
+
+        Returns:
+            :class:`telegram.File`
+
+        Raises:
+            :class:`telegram.TelegramError`
+
+        """
+        return self.bot.get_file(self.file_id, timeout=timeout, **kwargs)
+
 
 class StickerSet(TelegramObject):
     """This object represents a sticker set.
@@ -101,20 +127,23 @@ class StickerSet(TelegramObject):
     Attributes:
         name (:obj:`str`): Sticker set name.
         title (:obj:`str`): Sticker set title.
+        is_animated (:obj:`bool`): True, if the sticker set contains animated stickers.
         contains_masks (:obj:`bool`): True, if the sticker set contains masks.
         stickers (List[:class:`telegram.Sticker`]): List of all set stickers.
 
     Args:
         name (:obj:`str`): Sticker set name.
         title (:obj:`str`): Sticker set title.
+        is_animated (:obj:`bool`): True, if the sticker set contains animated stickers.
         contains_masks (:obj:`bool`): True, if the sticker set contains masks.
         stickers (List[:class:`telegram.Sticker`]): List of all set stickers.
 
     """
 
-    def __init__(self, name, title, contains_masks, stickers, bot=None, **kwargs):
+    def __init__(self, name, title, is_animated, contains_masks, stickers, bot=None, **kwargs):
         self.name = name
         self.title = title
+        self.is_animated = is_animated
         self.contains_masks = contains_masks
         self.stickers = stickers
 
