@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2017
+# Copyright (C) 2015-2020
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -22,6 +22,4 @@ from telegram import TelegramObject
 
 
 class CallbackGame(TelegramObject):
-    """
-    A placeholder, currently holds no information. Use BotFather to set up your game.
-    """
+    """A placeholder, currently holds no information. Use BotFather to set up your game."""
