@@ -2,7 +2,7 @@
 # pylint: disable=R0902,R0912,R0913
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2017
+# Copyright (C) 2015-2020
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-"""This module contains an object that represents a Telegram InlineQuery"""
+"""This module contains an object that represents a Telegram InlineQuery."""
 
 from telegram import TelegramObject, User, Location
 
@@ -35,7 +35,7 @@ class InlineQuery(TelegramObject):
         from_user (:class:`telegram.User`): Sender.
         location (:class:`telegram.Location`): Optional. Sender location, only for bots that
             request user location.
-        query (:obj:`str`): Text of the query (up to 512 characters).
+        query (:obj:`str`): Text of the query (up to 256 characters).
         offset (:obj:`str`): Offset of the results to be returned, can be controlled by the bot.
 
     Args:
@@ -43,10 +43,11 @@ class InlineQuery(TelegramObject):
         from_user (:class:`telegram.User`): Sender.
         location (:class:`telegram.Location`, optional): Sender location, only for bots that
             request user location.
-        query (:obj:`str`): Text of the query (up to 512 characters).
+        query (:obj:`str`): Text of the query (up to 256 characters).
         offset (:obj:`str`): Offset of the results to be returned, can be controlled by the bot.
         bot (:class:`telegram.Bot`, optional): The Bot to use for instance methods.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
+
     """
 
     def __init__(self, id, from_user, query, offset, location=None, bot=None, **kwargs):
@@ -74,19 +75,10 @@ class InlineQuery(TelegramObject):
 
         return cls(bot=bot, **data)
 
-    def to_dict(self):
-        data = super(InlineQuery, self).to_dict()
-
-        # Required
-        data['from'] = data.pop('from_user', None)
-
-        return data
-
     def answer(self, *args, **kwargs):
-        """
-        Shortcut for::
+        """Shortcut for::
 
-                bot.answer_inline_query(update.inline_query.id, *args, **kwargs)
+            bot.answer_inline_query(update.inline_query.id, *args, **kwargs)
 
         Args:
             results (List[:class:`telegram.InlineQueryResult`]): A list of results for the inline
@@ -106,6 +98,6 @@ class InlineQuery(TelegramObject):
             switch_pm_parameter (:obj:`str`, optional): Deep-linking parameter for the /start
                 message sent to the bot when user presses the switch button. 1-64 characters,
                 only A-Z, a-z, 0-9, _ and - are allowed.
-        """
 
+        """
         return self.bot.answer_inline_query(self.id, *args, **kwargs)
