@@ -2,7 +2,7 @@
 # pylint: disable=C0103,W0622
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2018
+# Copyright (C) 2015-2020
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -71,26 +71,30 @@ class User(TelegramObject):
 
     @property
     def name(self):
-        """
-        :obj:`str`: Convenience property. If available, returns the user's :attr:`username`
-            prefixed with "@". If :attr:`username` is not available, returns :attr:`full_name`.
-
-        """
+        """:obj:`str`: Convenience property. If available, returns the user's :attr:`username`
+        prefixed with "@". If :attr:`username` is not available, returns :attr:`full_name`."""
         if self.username:
             return '@{}'.format(self.username)
         return self.full_name
 
     @property
     def full_name(self):
-        """
-        :obj:`str`: Convenience property. The user's :attr:`first_name`, followed by (if available)
-            :attr:`last_name`.
+        """:obj:`str`: Convenience property. The user's :attr:`first_name`, followed by (if
+        available) :attr:`last_name`."""
 
-        """
         if self.last_name:
             return u'{} {}'.format(self.first_name, self.last_name)
         return self.first_name
 
+    @property
+    def link(self):
+        """:obj:`str`: Convenience property. If :attr:`username` is available, returns a t.me link
+        of the user."""
+
+        if self.username:
+            return "https://t.me/{}".format(self.username)
+        return None
+
     @classmethod
     def de_json(cls, data, bot):
         if not data:
@@ -124,33 +128,33 @@ class User(TelegramObject):
     def mention_markdown(self, name=None):
         """
         Args:
-            name (:obj:`str`): If provided, will overwrite the user's name.
+            name (:obj:`str`): The name used as a link for the user. Defaults to :attr:`full_name`.
 
         Returns:
             :obj:`str`: The inline mention for the user as markdown.
+
         """
-        if not name:
-            return util_mention_markdown(self.id, self.name)
-        else:
+        if name:
             return util_mention_markdown(self.id, name)
+        return util_mention_markdown(self.id, self.full_name)
 
     def mention_html(self, name=None):
         """
         Args:
-            name (:obj:`str`): If provided, will overwrite the user's name.
+            name (:obj:`str`): The name used as a link for the user. Defaults to :attr:`full_name`.
 
         Returns:
             :obj:`str`: The inline mention for the user as HTML.
+
         """
-        if not name:
-            return util_mention_html(self.id, self.name)
-        else:
+        if name:
             return util_mention_html(self.id, name)
+        return util_mention_html(self.id, self.full_name)
 
     def send_message(self, *args, **kwargs):
         """Shortcut for::
 
-            bot.send_message(User.chat_id, *args, **kwargs)
+            bot.send_message(User.id, *args, **kwargs)
 
         Where User is the current instance.
 
@@ -163,7 +167,7 @@ class User(TelegramObject):
     def send_photo(self, *args, **kwargs):
         """Shortcut for::
 
-            bot.send_photo(User.chat_id, *args, **kwargs)
+            bot.send_photo(User.id, *args, **kwargs)
 
         Where User is the current instance.
 
@@ -176,7 +180,7 @@ class User(TelegramObject):
     def send_audio(self, *args, **kwargs):
         """Shortcut for::
 
-            bot.send_audio(User.chat_id, *args, **kwargs)
+            bot.send_audio(User.id, *args, **kwargs)
 
         Where User is the current instance.
 
@@ -189,7 +193,7 @@ class User(TelegramObject):
     def send_document(self, *args, **kwargs):
         """Shortcut for::
 
-            bot.send_document(User.chat_id, *args, **kwargs)
+            bot.send_document(User.id, *args, **kwargs)
 
         Where User is the current instance.
 
@@ -199,10 +203,23 @@ class User(TelegramObject):
         """
         return self.bot.send_document(self.id, *args, **kwargs)
 
+    def send_animation(self, *args, **kwargs):
+        """Shortcut for::
+
+            bot.send_animation(User.id, *args, **kwargs)
+
+        Where User is the current instance.
+
+        Returns:
+            :class:`telegram.Message`: On success, instance representing the message posted.
+
+        """
+        return self.bot.send_animation(self.id, *args, **kwargs)
+
     def send_sticker(self, *args, **kwargs):
         """Shortcut for::
 
-            bot.send_sticker(User.chat_id, *args, **kwargs)
+            bot.send_sticker(User.id, *args, **kwargs)
 
         Where User is the current instance.
 
@@ -215,7 +232,7 @@ class User(TelegramObject):
     def send_video(self, *args, **kwargs):
         """Shortcut for::
 
-            bot.send_video(User.chat_id, *args, **kwargs)
+            bot.send_video(User.id, *args, **kwargs)
 
         Where User is the current instance.
 
@@ -228,7 +245,7 @@ class User(TelegramObject):
     def send_video_note(self, *args, **kwargs):
         """Shortcut for::
 
-            bot.send_video_note(User.chat_id, *args, **kwargs)
+            bot.send_video_note(User.id, *args, **kwargs)
 
         Where User is the current instance.
 
@@ -241,7 +258,7 @@ class User(TelegramObject):
     def send_voice(self, *args, **kwargs):
         """Shortcut for::
 
-            bot.send_voice(User.chat_id, *args, **kwargs)
+            bot.send_voice(User.id, *args, **kwargs)
 
         Where User is the current instance.
 
