@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2017
+# Copyright (C) 2015-2020
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -22,10 +22,7 @@ from telegram import PhotoSize, TelegramObject
 
 
 class UserProfilePhotos(TelegramObject):
-    """
-    This object represents a Telegram UserProfilePhotos.
-
-    This object represent a user's profile pictures.
+    """This object represent a user's profile pictures.
 
     Attributes:
         total_count (:obj:`int`): Total number of profile pictures.
@@ -35,6 +32,7 @@ class UserProfilePhotos(TelegramObject):
         total_count (:obj:`int`): Total number of profile pictures the target user has.
         photos (List[List[:class:`telegram.PhotoSize`]]): Requested profile pictures (in up to 4
             sizes each).
+
     """
 
     def __init__(self, total_count, photos, **kwargs):
