@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2018
+# Copyright (C) 2015-2020
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,9 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 import signal
+import sys
 
-from telegram.utils.helpers import enocde_conversations_to_json
+from telegram.utils.helpers import encode_conversations_to_json
 
 try:
     import ujson as json
@@ -38,7 +39,12 @@ from telegram.ext import BasePersistence, Updater, ConversationHandler, MessageH
 
 @pytest.fixture(scope="function")
 def base_persistence():
-    return BasePersistence(store_chat_data=True, store_user_data=True)
+    return BasePersistence(store_chat_data=True, store_user_data=True, store_bot_data=True)
+
+
+@pytest.fixture(scope="function")
+def bot_data():
+    return {'test1': 'test2', 'test3': {'test4': 'test5'}}
 
 
 @pytest.fixture(scope="function")
@@ -54,14 +60,17 @@ def user_data():
 @pytest.fixture(scope='function')
 def conversations():
     return {'name1': {(123, 123): 3, (456, 654): 4},
-            'name2': {(123, 321): 1, (890, 890): 2}}
+            'name2': {(123, 321): 1, (890, 890): 2},
+            'name3': {(123, 321): 1, (890, 890): 2}}
 
 
 @pytest.fixture(scope="function")
 def updater(bot, base_persistence):
     base_persistence.store_chat_data = False
+    base_persistence.store_bot_data = False
     base_persistence.store_user_data = False
     u = Updater(bot=bot, persistence=base_persistence)
+    base_persistence.store_bot_data = True
     base_persistence.store_chat_data = True
     base_persistence.store_user_data = True
     return u
@@ -72,12 +81,16 @@ class TestBasePersistence(object):
     def test_creation(self, base_persistence):
         assert base_persistence.store_chat_data
         assert base_persistence.store_user_data
+        with pytest.raises(NotImplementedError):
+            base_persistence.get_bot_data()
         with pytest.raises(NotImplementedError):
             base_persistence.get_chat_data()
         with pytest.raises(NotImplementedError):
             base_persistence.get_user_data()
         with pytest.raises(NotImplementedError):
             base_persistence.get_conversations("test")
+        with pytest.raises(NotImplementedError):
+            base_persistence.update_bot_data(None)
         with pytest.raises(NotImplementedError):
             base_persistence.update_chat_data(None, None)
         with pytest.raises(NotImplementedError):
@@ -98,15 +111,21 @@ class TestBasePersistence(object):
         with pytest.raises(NotImplementedError):
             dp.add_handler(ConversationHandler([], {}, [], persistent=True, name="My Handler"))
 
-    def test_dispatcher_integration_init(self, bot, base_persistence, chat_data, user_data):
+    def test_dispatcher_integration_init(self, bot, base_persistence, chat_data, user_data,
+                                         bot_data):
         def get_user_data():
             return "test"
 
         def get_chat_data():
             return "test"
 
+        def get_bot_data():
+            return "test"
+
         base_persistence.get_user_data = get_user_data
         base_persistence.get_chat_data = get_chat_data
+        base_persistence.get_bot_data = get_bot_data
+
         with pytest.raises(ValueError, match="user_data must be of type defaultdict"):
             u = Updater(bot=bot, persistence=base_persistence)
 
@@ -121,22 +140,34 @@ class TestBasePersistence(object):
             return chat_data
 
         base_persistence.get_chat_data = get_chat_data
+        with pytest.raises(ValueError, match="bot_data must be of type dict"):
+            u = Updater(bot=bot, persistence=base_persistence)
+
+        def get_bot_data():
+            return bot_data
+
+        base_persistence.get_bot_data = get_bot_data
         u = Updater(bot=bot, persistence=base_persistence)
+        assert u.dispatcher.bot_data == bot_data
         assert u.dispatcher.chat_data == chat_data
         assert u.dispatcher.user_data == user_data
         u.dispatcher.chat_data[442233]['test5'] = 'test6'
         assert u.dispatcher.chat_data[442233]['test5'] == 'test6'
 
     def test_dispatcher_integration_handlers(self, caplog, bot, base_persistence,
-                                             chat_data, user_data):
+                                             chat_data, user_data, bot_data):
         def get_user_data():
             return user_data
 
         def get_chat_data():
             return chat_data
 
+        def get_bot_data():
+            return bot_data
+
         base_persistence.get_user_data = get_user_data
         base_persistence.get_chat_data = get_chat_data
+        base_persistence.get_bot_data = get_bot_data
         # base_persistence.update_chat_data = lambda x: x
         # base_persistence.update_user_data = lambda x: x
         updater = Updater(bot=bot, persistence=base_persistence, use_context=True)
@@ -145,18 +176,25 @@ class TestBasePersistence(object):
         def callback_known_user(update, context):
             if not context.user_data['test1'] == 'test2':
                 pytest.fail('user_data corrupt')
+            if not context.bot_data == bot_data:
+                pytest.fail('bot_data corrupt')
 
         def callback_known_chat(update, context):
             if not context.chat_data['test3'] == 'test4':
                 pytest.fail('chat_data corrupt')
+            if not context.bot_data == bot_data:
+                pytest.fail('bot_data corrupt')
 
         def callback_unknown_user_or_chat(update, context):
             if not context.user_data == {}:
                 pytest.fail('user_data corrupt')
             if not context.chat_data == {}:
                 pytest.fail('chat_data corrupt')
+            if not context.bot_data == bot_data:
+                pytest.fail('bot_data corrupt')
             context.user_data[1] = 'test7'
             context.chat_data[2] = 'test8'
+            context.bot_data['test0'] = 'test0'
 
         known_user = MessageHandler(Filters.user(user_id=12345), callback_known_user,
                                     pass_chat_data=True, pass_user_data=True)
@@ -188,6 +226,10 @@ class TestBasePersistence(object):
         m.chat = chat2
         u = Update(2, m)
 
+        def save_bot_data(data):
+            if 'test0' not in data:
+                pytest.fail()
+
         def save_chat_data(data):
             if -987654 not in data:
                 pytest.fail()
@@ -198,10 +240,12 @@ class TestBasePersistence(object):
 
         base_persistence.update_chat_data = save_chat_data
         base_persistence.update_user_data = save_user_data
+        base_persistence.update_bot_data = save_bot_data
         dp.process_update(u)
 
         assert dp.user_data[54321][1] == 'test7'
         assert dp.chat_data[-987654][2] == 'test8'
+        assert dp.bot_data['test0'] == 'test0'
 
     def test_persistence_dispatcher_arbitrary_update_types(self, dp, base_persistence, caplog):
         # Updates used with TypeHandler doesn't necessarily have the proper attributes for
@@ -224,6 +268,17 @@ def pickle_persistence():
     return PicklePersistence(filename='pickletest',
                              store_user_data=True,
                              store_chat_data=True,
+                             store_bot_data=True,
+                             single_file=False,
+                             on_flush=False)
+
+
+@pytest.fixture(scope='function')
+def pickle_persistence_only_bot():
+    return PicklePersistence(filename='pickletest',
+                             store_user_data=False,
+                             store_chat_data=False,
+                             store_bot_data=True,
                              single_file=False,
                              on_flush=False)
 
@@ -233,6 +288,7 @@ def pickle_persistence_only_chat():
     return PicklePersistence(filename='pickletest',
                              store_user_data=False,
                              store_chat_data=True,
+                             store_bot_data=False,
                              single_file=False,
                              on_flush=False)
 
@@ -242,24 +298,45 @@ def pickle_persistence_only_user():
     return PicklePersistence(filename='pickletest',
                              store_user_data=True,
                              store_chat_data=False,
+                             store_bot_data=False,
                              single_file=False,
                              on_flush=False)
 
 
 @pytest.fixture(scope='function')
 def bad_pickle_files():
-    for name in ['pickletest_user_data', 'pickletest_chat_data', 'pickletest_conversations',
-                 'pickletest']:
+    for name in ['pickletest_user_data', 'pickletest_chat_data', 'pickletest_bot_data',
+                 'pickletest_conversations', 'pickletest']:
         with open(name, 'w') as f:
             f.write('(())')
     yield True
-    for name in ['pickletest_user_data', 'pickletest_chat_data', 'pickletest_conversations',
-                 'pickletest']:
+    for name in ['pickletest_user_data', 'pickletest_chat_data', 'pickletest_bot_data',
+                 'pickletest_conversations', 'pickletest']:
         os.remove(name)
 
 
 @pytest.fixture(scope='function')
-def good_pickle_files(user_data, chat_data, conversations):
+def good_pickle_files(user_data, chat_data, bot_data, conversations):
+    all = {'user_data': user_data, 'chat_data': chat_data,
+           'bot_data': bot_data, 'conversations': conversations}
+    with open('pickletest_user_data', 'wb') as f:
+        pickle.dump(user_data, f)
+    with open('pickletest_chat_data', 'wb') as f:
+        pickle.dump(chat_data, f)
+    with open('pickletest_bot_data', 'wb') as f:
+        pickle.dump(bot_data, f)
+    with open('pickletest_conversations', 'wb') as f:
+        pickle.dump(conversations, f)
+    with open('pickletest', 'wb') as f:
+        pickle.dump(all, f)
+    yield True
+    for name in ['pickletest_user_data', 'pickletest_chat_data', 'pickletest_bot_data',
+                 'pickletest_conversations', 'pickletest']:
+        os.remove(name)
+
+
+@pytest.fixture(scope='function')
+def pickle_files_wo_bot_data(user_data, chat_data, conversations):
     all = {'user_data': user_data, 'chat_data': chat_data, 'conversations': conversations}
     with open('pickletest_user_data', 'wb') as f:
         pickle.dump(user_data, f)
@@ -270,8 +347,8 @@ def good_pickle_files(user_data, chat_data, conversations):
     with open('pickletest', 'wb') as f:
         pickle.dump(all, f)
     yield True
-    for name in ['pickletest_user_data', 'pickletest_chat_data', 'pickletest_conversations',
-                 'pickletest']:
+    for name in ['pickletest_user_data', 'pickletest_chat_data',
+                 'pickletest_conversations', 'pickletest']:
         os.remove(name)
 
 
@@ -289,6 +366,8 @@ class TestPickelPersistence(object):
         assert pickle_persistence.get_user_data() == defaultdict(dict)
         assert pickle_persistence.get_chat_data() == defaultdict(dict)
         assert pickle_persistence.get_chat_data() == defaultdict(dict)
+        assert pickle_persistence.get_bot_data() == {}
+        assert pickle_persistence.get_bot_data() == {}
         assert pickle_persistence.get_conversations('noname') == {}
         assert pickle_persistence.get_conversations('noname') == {}
 
@@ -296,6 +375,7 @@ class TestPickelPersistence(object):
         pickle_persistence.single_file = True
         assert pickle_persistence.get_user_data() == defaultdict(dict)
         assert pickle_persistence.get_chat_data() == defaultdict(dict)
+        assert pickle_persistence.get_chat_data() == {}
         assert pickle_persistence.get_conversations('noname') == {}
 
     def test_with_bad_multi_file(self, pickle_persistence, bad_pickle_files):
@@ -303,6 +383,8 @@ class TestPickelPersistence(object):
             pickle_persistence.get_user_data()
         with pytest.raises(TypeError, match='pickletest_chat_data'):
             pickle_persistence.get_chat_data()
+        with pytest.raises(TypeError, match='pickletest_bot_data'):
+            pickle_persistence.get_bot_data()
         with pytest.raises(TypeError, match='pickletest_conversations'):
             pickle_persistence.get_conversations('name')
 
@@ -312,6 +394,8 @@ class TestPickelPersistence(object):
             pickle_persistence.get_user_data()
         with pytest.raises(TypeError, match='pickletest'):
             pickle_persistence.get_chat_data()
+        with pytest.raises(TypeError, match='pickletest'):
+            pickle_persistence.get_bot_data()
         with pytest.raises(TypeError, match='pickletest'):
             pickle_persistence.get_conversations('name')
 
@@ -328,6 +412,12 @@ class TestPickelPersistence(object):
         assert chat_data[-67890][3] == 'test4'
         assert chat_data[-54321] == {}
 
+        bot_data = pickle_persistence.get_bot_data()
+        assert isinstance(bot_data, dict)
+        assert bot_data['test1'] == 'test2'
+        assert bot_data['test3']['test4'] == 'test5'
+        assert 'test0' not in bot_data
+
         conversation1 = pickle_persistence.get_conversations('name1')
         assert isinstance(conversation1, dict)
         assert conversation1[(123, 123)] == 3
@@ -355,6 +445,12 @@ class TestPickelPersistence(object):
         assert chat_data[-67890][3] == 'test4'
         assert chat_data[-54321] == {}
 
+        bot_data = pickle_persistence.get_bot_data()
+        assert isinstance(bot_data, dict)
+        assert bot_data['test1'] == 'test2'
+        assert bot_data['test3']['test4'] == 'test5'
+        assert 'test0' not in bot_data
+
         conversation1 = pickle_persistence.get_conversations('name1')
         assert isinstance(conversation1, dict)
         assert conversation1[(123, 123)] == 3
@@ -368,6 +464,54 @@ class TestPickelPersistence(object):
         with pytest.raises(KeyError):
             conversation2[(123, 123)]
 
+    def test_with_multi_file_wo_bot_data(self, pickle_persistence, pickle_files_wo_bot_data):
+        user_data = pickle_persistence.get_user_data()
+        assert isinstance(user_data, defaultdict)
+        assert user_data[12345]['test1'] == 'test2'
+        assert user_data[67890][3] == 'test4'
+        assert user_data[54321] == {}
+
+        chat_data = pickle_persistence.get_chat_data()
+        assert isinstance(chat_data, defaultdict)
+        assert chat_data[-12345]['test1'] == 'test2'
+        assert chat_data[-67890][3] == 'test4'
+        assert chat_data[-54321] == {}
+
+        bot_data = pickle_persistence.get_bot_data()
+        assert isinstance(bot_data, dict)
+        assert not bot_data.keys()
+
+        conversation1 = pickle_persistence.get_conversations('name1')
+        assert isinstance(conversation1, dict)
+        assert conversation1[(123, 123)] == 3
+        assert conversation1[(456, 654)] == 4
+        with pytest.raises(KeyError):
+            conversation1[(890, 890)]
+        conversation2 = pickle_persistence.get_conversations('name2')
+        assert isinstance(conversation1, dict)
+        assert conversation2[(123, 321)] == 1
+        assert conversation2[(890, 890)] == 2
+        with pytest.raises(KeyError):
+            conversation2[(123, 123)]
+
+    def test_with_single_file_wo_bot_data(self, pickle_persistence, pickle_files_wo_bot_data):
+        pickle_persistence.single_file = True
+        user_data = pickle_persistence.get_user_data()
+        assert isinstance(user_data, defaultdict)
+        assert user_data[12345]['test1'] == 'test2'
+        assert user_data[67890][3] == 'test4'
+        assert user_data[54321] == {}
+
+        chat_data = pickle_persistence.get_chat_data()
+        assert isinstance(chat_data, defaultdict)
+        assert chat_data[-12345]['test1'] == 'test2'
+        assert chat_data[-67890][3] == 'test4'
+        assert chat_data[-54321] == {}
+
+        bot_data = pickle_persistence.get_bot_data()
+        assert isinstance(bot_data, dict)
+        assert not bot_data.keys()
+
     def test_updating_multi_file(self, pickle_persistence, good_pickle_files):
         user_data = pickle_persistence.get_user_data()
         user_data[54321]['test9'] = 'test 10'
@@ -387,6 +531,15 @@ class TestPickelPersistence(object):
             chat_data_test = defaultdict(dict, pickle.load(f))
         assert chat_data_test == chat_data
 
+        bot_data = pickle_persistence.get_bot_data()
+        bot_data['test6'] = 'test 7'
+        assert not pickle_persistence.bot_data == bot_data
+        pickle_persistence.update_bot_data(bot_data)
+        assert pickle_persistence.bot_data == bot_data
+        with open('pickletest_bot_data', 'rb') as f:
+            bot_data_test = pickle.load(f)
+        assert bot_data_test == bot_data
+
         conversation1 = pickle_persistence.get_conversations('name1')
         conversation1[(123, 123)] = 5
         assert not pickle_persistence.conversations['name1'] == conversation1
@@ -417,6 +570,15 @@ class TestPickelPersistence(object):
             chat_data_test = defaultdict(dict, pickle.load(f)['chat_data'])
         assert chat_data_test == chat_data
 
+        bot_data = pickle_persistence.get_bot_data()
+        bot_data['test6'] = 'test 7'
+        assert not pickle_persistence.bot_data == bot_data
+        pickle_persistence.update_bot_data(bot_data)
+        assert pickle_persistence.bot_data == bot_data
+        with open('pickletest', 'rb') as f:
+            bot_data_test = pickle.load(f)['bot_data']
+        assert bot_data_test == bot_data
+
         conversation1 = pickle_persistence.get_conversations('name1')
         conversation1[(123, 123)] = 5
         assert not pickle_persistence.conversations['name1'] == conversation1
@@ -453,6 +615,17 @@ class TestPickelPersistence(object):
             chat_data_test = defaultdict(dict, pickle.load(f))
         assert not chat_data_test == chat_data
 
+        bot_data = pickle_persistence.get_bot_data()
+        bot_data['test6'] = 'test 7'
+        assert not pickle_persistence.bot_data == bot_data
+
+        pickle_persistence.update_bot_data(bot_data)
+        assert pickle_persistence.bot_data == bot_data
+
+        with open('pickletest_bot_data', 'rb') as f:
+            bot_data_test = pickle.load(f)
+        assert not bot_data_test == bot_data
+
         conversation1 = pickle_persistence.get_conversations('name1')
         conversation1[(123, 123)] = 5
         assert not pickle_persistence.conversations['name1'] == conversation1
@@ -473,6 +646,10 @@ class TestPickelPersistence(object):
             chat_data_test = defaultdict(dict, pickle.load(f))
         assert chat_data_test == chat_data
 
+        with open('pickletest_bot_data', 'rb') as f:
+            bot_data_test = pickle.load(f)
+        assert bot_data_test == bot_data
+
         with open('pickletest_conversations', 'rb') as f:
             conversations_test = defaultdict(dict, pickle.load(f))
         assert conversations_test['name1'] == conversation1
@@ -502,6 +679,15 @@ class TestPickelPersistence(object):
             chat_data_test = defaultdict(dict, pickle.load(f)['chat_data'])
         assert not chat_data_test == chat_data
 
+        bot_data = pickle_persistence.get_bot_data()
+        bot_data['test6'] = 'test 7'
+        assert not pickle_persistence.bot_data == bot_data
+        pickle_persistence.update_bot_data(bot_data)
+        assert pickle_persistence.bot_data == bot_data
+        with open('pickletest', 'rb') as f:
+            bot_data_test = pickle.load(f)['bot_data']
+        assert not bot_data_test == bot_data
+
         conversation1 = pickle_persistence.get_conversations('name1')
         conversation1[(123, 123)] = 5
         assert not pickle_persistence.conversations['name1'] == conversation1
@@ -520,11 +706,15 @@ class TestPickelPersistence(object):
             chat_data_test = defaultdict(dict, pickle.load(f)['chat_data'])
         assert chat_data_test == chat_data
 
+        with open('pickletest', 'rb') as f:
+            bot_data_test = pickle.load(f)['bot_data']
+        assert bot_data_test == bot_data
+
         with open('pickletest', 'rb') as f:
             conversations_test = defaultdict(dict, pickle.load(f)['conversations'])
         assert conversations_test['name1'] == conversation1
 
-    def test_with_handler(self, bot, update, pickle_persistence, good_pickle_files):
+    def test_with_handler(self, bot, update, bot_data, pickle_persistence, good_pickle_files):
         u = Updater(bot=bot, persistence=pickle_persistence, use_context=True)
         dp = u.dispatcher
 
@@ -533,14 +723,19 @@ class TestPickelPersistence(object):
                 pytest.fail()
             if not context.chat_data == {}:
                 pytest.fail()
+            if not context.bot_data == bot_data:
+                pytest.fail()
             context.user_data['test1'] = 'test2'
             context.chat_data['test3'] = 'test4'
+            context.bot_data['test1'] = 'test0'
 
         def second(update, context):
             if not context.user_data['test1'] == 'test2':
                 pytest.fail()
             if not context.chat_data['test3'] == 'test4':
                 pytest.fail()
+            if not context.bot_data['test1'] == 'test0':
+                pytest.fail()
 
         h1 = MessageHandler(None, first, pass_user_data=True, pass_chat_data=True)
         h2 = MessageHandler(None, second, pass_user_data=True, pass_chat_data=True)
@@ -552,6 +747,7 @@ class TestPickelPersistence(object):
         pickle_persistence_2 = PicklePersistence(filename='pickletest',
                                                  store_user_data=True,
                                                  store_chat_data=True,
+                                                 store_bot_data=True,
                                                  single_file=False,
                                                  on_flush=False)
         u = Updater(bot=bot, persistence=pickle_persistence_2)
@@ -565,6 +761,7 @@ class TestPickelPersistence(object):
         u.running = True
         dp.user_data[4242424242]['my_test'] = 'Working!'
         dp.chat_data[-4242424242]['my_test2'] = 'Working2!'
+        dp.bot_data['test'] = 'Working3!'
         u.signal_handler(signal.SIGINT, None)
         del (dp)
         del (u)
@@ -576,10 +773,34 @@ class TestPickelPersistence(object):
                                                  on_flush=False)
         assert pickle_persistence_2.get_user_data()[4242424242]['my_test'] == 'Working!'
         assert pickle_persistence_2.get_chat_data()[-4242424242]['my_test2'] == 'Working2!'
+        assert pickle_persistence_2.get_bot_data()['test'] == 'Working3!'
 
-    def test_flush_on_stop_only_chat(self, bot, update, pickle_persistence_only_chat):
+    def test_flush_on_stop_only_bot(self, bot, update, pickle_persistence_only_bot):
         os.remove('pickletest_user_data')
         os.remove('pickletest_chat_data')
+        os.remove('pickletest_bot_data')
+        u = Updater(bot=bot, persistence=pickle_persistence_only_bot)
+        dp = u.dispatcher
+        u.running = True
+        dp.user_data[4242424242]['my_test'] = 'Working!'
+        dp.chat_data[-4242424242]['my_test2'] = 'Working2!'
+        dp.bot_data['my_test3'] = 'Working3!'
+        u.signal_handler(signal.SIGINT, None)
+        del (dp)
+        del (u)
+        del (pickle_persistence_only_bot)
+        pickle_persistence_2 = PicklePersistence(filename='pickletest',
+                                                 store_user_data=False,
+                                                 store_chat_data=False,
+                                                 store_bot_data=True,
+                                                 single_file=False,
+                                                 on_flush=False)
+        assert pickle_persistence_2.get_user_data() == {}
+        assert pickle_persistence_2.get_chat_data() == {}
+        assert pickle_persistence_2.get_bot_data()['my_test3'] == 'Working3!'
+
+    def test_flush_on_stop_only_chat(self, bot, update, pickle_persistence_only_chat):
+        os.remove('pickletest_bot_data')
         u = Updater(bot=bot, persistence=pickle_persistence_only_chat)
         dp = u.dispatcher
         u.running = True
@@ -592,10 +813,12 @@ class TestPickelPersistence(object):
         pickle_persistence_2 = PicklePersistence(filename='pickletest',
                                                  store_user_data=False,
                                                  store_chat_data=True,
+                                                 store_bot_data=False,
                                                  single_file=False,
                                                  on_flush=False)
         assert pickle_persistence_2.get_user_data() == {}
         assert pickle_persistence_2.get_chat_data()[-4242424242]['my_test2'] == 'Working2!'
+        assert pickle_persistence_2.get_bot_data() == {}
 
     def test_flush_on_stop_only_user(self, bot, update, pickle_persistence_only_user):
         os.remove('pickletest_chat_data')
@@ -611,10 +834,12 @@ class TestPickelPersistence(object):
         pickle_persistence_2 = PicklePersistence(filename='pickletest',
                                                  store_user_data=True,
                                                  store_chat_data=False,
+                                                 store_bot_data=False,
                                                  single_file=False,
                                                  on_flush=False)
         assert pickle_persistence_2.get_user_data()[4242424242]['my_test'] == 'Working!'
         assert pickle_persistence_2.get_chat_data()[-4242424242] == {}
+        assert pickle_persistence_2.get_bot_data() == {}
 
     def test_with_conversationHandler(self, dp, update, good_pickle_files, pickle_persistence):
         dp.persistence = pickle_persistence
@@ -648,10 +873,61 @@ class TestPickelPersistence(object):
         assert ch.conversations[ch._get_key(update)] == 0
         assert ch.conversations == pickle_persistence.conversations['name2']
 
+    def test_with_nested_conversationHandler(self, dp, update, good_pickle_files,
+                                             pickle_persistence):
+        dp.persistence = pickle_persistence
+        dp.use_context = True
+        NEXT2, NEXT3 = range(1, 3)
+
+        def start(update, context):
+            return NEXT2
+
+        start = CommandHandler('start', start)
+
+        def next(update, context):
+            return NEXT2
+
+        next = MessageHandler(None, next)
+
+        def next2(update, context):
+            return ConversationHandler.END
+
+        next2 = MessageHandler(None, next2)
+
+        nested_ch = ConversationHandler(
+            [next],
+            {NEXT2: [next2]},
+            [],
+            name='name3',
+            persistent=True,
+            map_to_parent={ConversationHandler.END: ConversationHandler.END},
+        )
+
+        ch = ConversationHandler([start], {NEXT2: [nested_ch], NEXT3: []}, [], name='name2',
+                                 persistent=True)
+        dp.add_handler(ch)
+        assert ch.conversations[ch._get_key(update)] == 1
+        assert nested_ch.conversations[nested_ch._get_key(update)] == 1
+        dp.process_update(update)
+        assert ch._get_key(update) not in ch.conversations
+        assert nested_ch._get_key(update) not in nested_ch.conversations
+        update.message.text = '/start'
+        update.message.entities = [MessageEntity(MessageEntity.BOT_COMMAND, 0, 6)]
+        dp.process_update(update)
+        assert ch.conversations[ch._get_key(update)] == 1
+        assert ch.conversations == pickle_persistence.conversations['name2']
+        assert nested_ch._get_key(update) not in nested_ch.conversations
+        dp.process_update(update)
+        assert ch.conversations[ch._get_key(update)] == 1
+        assert ch.conversations == pickle_persistence.conversations['name2']
+        assert nested_ch.conversations[nested_ch._get_key(update)] == 1
+        assert nested_ch.conversations == pickle_persistence.conversations['name3']
+
     @classmethod
     def teardown_class(cls):
         try:
             for name in ['pickletest_user_data', 'pickletest_chat_data',
+                         'pickletest_bot_data',
                          'pickletest_conversations',
                          'pickletest']:
                 os.remove(name)
@@ -669,9 +945,15 @@ def chat_data_json(chat_data):
     return json.dumps(chat_data)
 
 
+@pytest.fixture(scope='function')
+def bot_data_json(bot_data):
+    return json.dumps(bot_data)
+
+
 @pytest.fixture(scope='function')
 def conversations_json(conversations):
     return """{"name1": {"[123, 123]": 3, "[456, 654]": 4}, "name2":
+              {"[123, 321]": 1, "[890, 890]": 2}, "name3":
               {"[123, 321]": 1, "[890, 890]": 2}}"""
 
 
@@ -680,33 +962,42 @@ class TestDictPersistence(object):
         dict_persistence = DictPersistence()
         assert dict_persistence.get_user_data() == defaultdict(dict)
         assert dict_persistence.get_chat_data() == defaultdict(dict)
+        assert dict_persistence.get_bot_data() == {}
         assert dict_persistence.get_conversations('noname') == {}
 
     def test_bad_json_string_given(self):
         bad_user_data = 'thisisnojson99900()))('
         bad_chat_data = 'thisisnojson99900()))('
+        bad_bot_data = 'thisisnojson99900()))('
         bad_conversations = 'thisisnojson99900()))('
         with pytest.raises(TypeError, match='user_data'):
             DictPersistence(user_data_json=bad_user_data)
         with pytest.raises(TypeError, match='chat_data'):
             DictPersistence(chat_data_json=bad_chat_data)
+        with pytest.raises(TypeError, match='bot_data'):
+            DictPersistence(bot_data_json=bad_bot_data)
         with pytest.raises(TypeError, match='conversations'):
             DictPersistence(conversations_json=bad_conversations)
 
     def test_invalid_json_string_given(self, pickle_persistence, bad_pickle_files):
         bad_user_data = '["this", "is", "json"]'
         bad_chat_data = '["this", "is", "json"]'
+        bad_bot_data = '["this", "is", "json"]'
         bad_conversations = '["this", "is", "json"]'
         with pytest.raises(TypeError, match='user_data'):
             DictPersistence(user_data_json=bad_user_data)
         with pytest.raises(TypeError, match='chat_data'):
             DictPersistence(chat_data_json=bad_chat_data)
+        with pytest.raises(TypeError, match='bot_data'):
+            DictPersistence(bot_data_json=bad_bot_data)
         with pytest.raises(TypeError, match='conversations'):
             DictPersistence(conversations_json=bad_conversations)
 
-    def test_good_json_input(self, user_data_json, chat_data_json, conversations_json):
+    def test_good_json_input(self, user_data_json, chat_data_json, bot_data_json,
+                             conversations_json):
         dict_persistence = DictPersistence(user_data_json=user_data_json,
                                            chat_data_json=chat_data_json,
+                                           bot_data_json=bot_data_json,
                                            conversations_json=conversations_json)
         user_data = dict_persistence.get_user_data()
         assert isinstance(user_data, defaultdict)
@@ -720,6 +1011,12 @@ class TestDictPersistence(object):
         assert chat_data[-67890][3] == 'test4'
         assert chat_data[-54321] == {}
 
+        bot_data = dict_persistence.get_bot_data()
+        assert isinstance(bot_data, dict)
+        assert bot_data['test1'] == 'test2'
+        assert bot_data['test3']['test4'] == 'test5'
+        assert 'test6' not in bot_data
+
         conversation1 = dict_persistence.get_conversations('name1')
         assert isinstance(conversation1, dict)
         assert conversation1[(123, 123)] == 3
@@ -734,26 +1031,35 @@ class TestDictPersistence(object):
             conversation2[(123, 123)]
 
     def test_dict_outputs(self, user_data, user_data_json, chat_data, chat_data_json,
+                          bot_data, bot_data_json,
                           conversations, conversations_json):
         dict_persistence = DictPersistence(user_data_json=user_data_json,
                                            chat_data_json=chat_data_json,
+                                           bot_data_json=bot_data_json,
                                            conversations_json=conversations_json)
         assert dict_persistence.user_data == user_data
         assert dict_persistence.chat_data == chat_data
+        assert dict_persistence.bot_data == bot_data
         assert dict_persistence.conversations == conversations
 
-    def test_json_outputs(self, user_data_json, chat_data_json, conversations_json):
+    @pytest.mark.skipif(sys.version_info < (3, 6), reason="dicts are not ordered in py<=3.5")
+    def test_json_outputs(self, user_data_json, chat_data_json, bot_data_json, conversations_json):
         dict_persistence = DictPersistence(user_data_json=user_data_json,
                                            chat_data_json=chat_data_json,
+                                           bot_data_json=bot_data_json,
                                            conversations_json=conversations_json)
         assert dict_persistence.user_data_json == user_data_json
         assert dict_persistence.chat_data_json == chat_data_json
+        assert dict_persistence.bot_data_json == bot_data_json
         assert dict_persistence.conversations_json == conversations_json
 
+    @pytest.mark.skipif(sys.version_info < (3, 6), reason="dicts are not ordered in py<=3.5")
     def test_json_changes(self, user_data, user_data_json, chat_data, chat_data_json,
+                          bot_data, bot_data_json,
                           conversations, conversations_json):
         dict_persistence = DictPersistence(user_data_json=user_data_json,
                                            chat_data_json=chat_data_json,
+                                           bot_data_json=bot_data_json,
                                            conversations_json=conversations_json)
         user_data_two = user_data.copy()
         user_data_two.update({4: {5: 6}})
@@ -769,12 +1075,20 @@ class TestDictPersistence(object):
         assert dict_persistence.chat_data_json != chat_data_json
         assert dict_persistence.chat_data_json == json.dumps(chat_data_two)
 
+        bot_data_two = bot_data.copy()
+        bot_data_two.update({'7': {'8': '9'}})
+        bot_data['7'] = {'8': '9'}
+        dict_persistence.update_bot_data(bot_data)
+        assert dict_persistence.bot_data == bot_data_two
+        assert dict_persistence.bot_data_json != bot_data_json
+        assert dict_persistence.bot_data_json == json.dumps(bot_data_two)
+
         conversations_two = conversations.copy()
-        conversations_two.update({'name3': {(1, 2): 3}})
-        dict_persistence.update_conversation('name3', (1, 2), 3)
+        conversations_two.update({'name4': {(1, 2): 3}})
+        dict_persistence.update_conversation('name4', (1, 2), 3)
         assert dict_persistence.conversations == conversations_two
         assert dict_persistence.conversations_json != conversations_json
-        assert dict_persistence.conversations_json == enocde_conversations_to_json(
+        assert dict_persistence.conversations_json == encode_conversations_to_json(
             conversations_two)
 
     def test_with_handler(self, bot, update):
@@ -787,14 +1101,19 @@ class TestDictPersistence(object):
                 pytest.fail()
             if not context.chat_data == {}:
                 pytest.fail()
+            if not context.bot_data == {}:
+                pytest.fail()
             context.user_data['test1'] = 'test2'
             context.chat_data[3] = 'test4'
+            context.bot_data['test1'] = 'test2'
 
         def second(update, context):
             if not context.user_data['test1'] == 'test2':
                 pytest.fail()
             if not context.chat_data[3] == 'test4':
                 pytest.fail()
+            if not context.bot_data['test1'] == 'test2':
+                pytest.fail()
 
         h1 = MessageHandler(None, first, pass_user_data=True, pass_chat_data=True)
         h2 = MessageHandler(None, second, pass_user_data=True, pass_chat_data=True)
@@ -804,9 +1123,11 @@ class TestDictPersistence(object):
         del (u)
         user_data = dict_persistence.user_data_json
         chat_data = dict_persistence.chat_data_json
+        bot_data = dict_persistence.bot_data_json
         del (dict_persistence)
         dict_persistence_2 = DictPersistence(user_data_json=user_data,
-                                             chat_data_json=chat_data)
+                                             chat_data_json=chat_data,
+                                             bot_data_json=bot_data)
 
         u = Updater(bot=bot, persistence=dict_persistence_2)
         dp = u.dispatcher
@@ -845,3 +1166,53 @@ class TestDictPersistence(object):
         dp.process_update(update)
         assert ch.conversations[ch._get_key(update)] == 0
         assert ch.conversations == dict_persistence.conversations['name2']
+
+    def test_with_nested_conversationHandler(self, dp, update, conversations_json):
+        dict_persistence = DictPersistence(conversations_json=conversations_json)
+        dp.persistence = dict_persistence
+        dp.use_context = True
+        NEXT2, NEXT3 = range(1, 3)
+
+        def start(update, context):
+            return NEXT2
+
+        start = CommandHandler('start', start)
+
+        def next(update, context):
+            return NEXT2
+
+        next = MessageHandler(None, next)
+
+        def next2(update, context):
+            return ConversationHandler.END
+
+        next2 = MessageHandler(None, next2)
+
+        nested_ch = ConversationHandler(
+            [next],
+            {NEXT2: [next2]},
+            [],
+            name='name3',
+            persistent=True,
+            map_to_parent={ConversationHandler.END: ConversationHandler.END},
+        )
+
+        ch = ConversationHandler([start], {NEXT2: [nested_ch], NEXT3: []}, [], name='name2',
+                                 persistent=True)
+        dp.add_handler(ch)
+        assert ch.conversations[ch._get_key(update)] == 1
+        assert nested_ch.conversations[nested_ch._get_key(update)] == 1
+        dp.process_update(update)
+        assert ch._get_key(update) not in ch.conversations
+        assert nested_ch._get_key(update) not in nested_ch.conversations
+        update.message.text = '/start'
+        update.message.entities = [MessageEntity(MessageEntity.BOT_COMMAND, 0, 6)]
+        dp.process_update(update)
+        assert ch.conversations[ch._get_key(update)] == 1
+        assert ch.conversations == dict_persistence.conversations['name2']
+        assert nested_ch._get_key(update) not in nested_ch.conversations
+        dp.process_update(update)
+        assert ch.conversations[ch._get_key(update)] == 1
+        assert ch.conversations == dict_persistence.conversations['name2']
+        assert nested_ch.conversations[nested_ch._get_key(update)] == 1
+        assert nested_ch.conversations == dict_persistence.conversations['name3']
