@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2018
+# Copyright (C) 2015-2020
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -23,12 +23,22 @@ from telegram import TelegramError
 from telegram.utils.request import Request
 
 
-def test_parse_illegal_callback_data():
+def test_replaced_unprintable_char():
     """
     Clients can send arbitrary bytes in callback data.
     Make sure the correct error is raised in this case.
     """
-    server_response = b'{"invalid utf-8": "\x80"}'
+    server_response = b'{"invalid utf-8": "\x80", "result": "KUKU"}'
 
-    with pytest.raises(TelegramError, match='Server response could not be decoded using UTF-8'):
+    assert Request._parse(server_response) == 'KUKU'
+
+
+def test_parse_illegal_json():
+    """
+    Clients can send arbitrary bytes in callback data.
+    Make sure the correct error is raised in this case.
+    """
+    server_response = b'{"invalid utf-8": "\x80", result: "KUKU"}'
+
+    with pytest.raises(TelegramError, match='Invalid server response'):
         Request._parse(server_response)
